from prompt_toolkit.styles import Style, merge_styles

override_style = Style([("bottom-toolbar", "noreverse")])

style = REDIS_TOKEN = {
    "key": "#33aa33",
    "important-key": "#058B06",
    "pattern": "bold #33aa33",
    "string": "#FD971F",
    "member": "#FD971F",
    "command": "bold #008000",
    "integer": "#AE81FF",
    "start": "#AE81FF",  # TODO auto merge with integer
    "end": "#AE81FF",
    "const": "bold #AE81FF",
    "time": "#aa22ff",
    "double": "#bb6688",
    "nil": "#808080",
    "bit": "#8541FF",
    "field": "cyan",
}

DOC = {
    "doccommand": "bold",
    "dockey": "#E6DB74",
    "code": "#aaaaaa",
    "h2": "bold #33aa33",
}

GROUP = {
    "group.cluster": "#E6DB74",
    "group.connection": "#E6DB74",
    "group.generic": "#E6DB74",
    "group.geo": "#E6DB74",
    "group.hash": "#E6DB74",
    "group.hyperloglog": "#E6DB74",
    "group.list": "#E6DB74",
    "group.pubsub": "#E6DB74",
    "group.server": "#E6DB74",
    "group.set": "#E6DB74",
    "group.sortedset": "#E6DB74",
    "group.stram": "#E6DB74",
    "group.string": "#E6DB74",
    "group.transections": "#E6DB74",
}


STYLE_DICT = {
    # User input (default text).
    "": "",
    # Prompt.
    "rprompt": "bg:#ff0066 #ffffff",
    "hostname": "",
    "index": "#ff0000",
    "trailing-input": "bg:#ff0000 #000000",
    "password": "hidden",
    "success": "#00ff5f bold",
    "queued": "#32CD32 bold",
    "error": "#ff005f bold",
    "type": "#888",
    "channel": "#888",  # FIXME
    # colors below copied from mycli project, ~~love~~
    # bottom-toolbar
    "bottom-toolbar": "bg:#222222 #aaaaaa",
    "bottom-toolbar.on": "bg:#222222 #ffffff",
    "bottom-toolbar.off": "bg:#222222 #888888",
    "bottom-toolbar.loaded": "bg:#222222 #44aa44",
    "bottom-toolbar.since": "bg:#222222 #bc7a00",
    "bottom-toolbar.complexity": "bg:#222222 #666666",
    "bottom-toolbar.group": "bg:#222222 #d2413a bold",
    # completion
    "completion-menu.completion.current": "bg:#ffffff #000000",
    "completion-menu.completion": "bg:#008888 #ffffff",
    "completion-menu.meta.completion.current": "bg:#44aaaa #000000",
    "completion-menu.meta.completion": "bg:#448888 #ffffff",
    "completion-menu.multi-column-meta": "bg:#aaffff #000000",
    "scrollbar.arrow": "bg:#003333",
    "scrollbar": "bg:#00aaaa",
    "selected": "#ffffff bg:#6666aa",
    "search": "#ffffff bg:#4444aa",
    "search.current": "#ffffff bg:#44aa44",
    "search-toolbar": "noinherit bold",
    "search-toolbar.text": "nobold",
    "system-toolbar": "noinherit bold",
    "arg-toolbar": "noinherit bold",
    "arg-toolbar.text": "nobold",
}

BOTTOM_TOOLBAR_TOKEN = {
    # redis token
    f"bottom-toolbar.{token}": f"bg:#222222 {token_style}"
    for token, token_style in REDIS_TOKEN.items()
}

style.update(STYLE_DICT)
style.update(BOTTOM_TOOLBAR_TOKEN)
style.update(DOC)


STYLE = merge_styles([override_style, Style.from_dict(style)])



COMPILING_IN_PROGRESS = 0
COMPILING_JUST_FINISH = 1
COMPILING_DONE = 2


class Config:
    """
    Global config, set once on start, then
    become readonly, never change again.

    :param raw: weather write raw bytes to stdout without any
        decoding.
    :param decode: How to decode bytes response.(For display and
        Completers)
        default is None, means show literal bytes. But completers
        will try use utf-8 decoding.
    """

    def __init__(self):
        self.raw = False
        self.decode = None
        self.compiling = COMPILING_IN_PROGRESS  # is loading redis commands?
        self.completer_max = 300
        self.transaction = False
        # for transaction render
        self.queued_commands = []
        # show command hint?
        self.newbie_mode = False
        # display zset withscores?
        self.withscores = False
        self.version = "Unknown"
        self.no_version_reason = None

    def __setter__(self, name, value):
        # for every time start a transaction
        # clear the queued commands first
        if name == "transaction" and value is True:
            self.queued_commands = []
        super().__setattr__(name, value)


config = Config()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['iredis']

package_data = \
{'': ['*'], 'iredis': ['data/*']}

install_requires = \
['Pygments>=2,<3',
 'click8>=8,<9',
 'mistune>=0.8.4,<0.9.0',
 'prompt_toolkit>=2,<3',
 'redis>=3,<4']

entry_points = \
{'console_scripts': ['iredis = iredis.entry:main']}

setup_kwargs = {
    'name': 'iredis',
    'version': '0.6.0',
    'description': 'Terminal client for Redis with auto-completion and syntax highlighting.',
    'long_description': '# IRedis (Interactive Redis)\n\n<img align="right" width="100" height="100" src="https://raw.githubusercontent.com/laixintao/iredis/master/docs/assets/logo.png" />\n\n[![CircleCI](https://circleci.com/gh/laixintao/iredis.svg?style=svg)](https://circleci.com/gh/laixintao/iredis)\n[![PyPI version](https://badge.fury.io/py/iredis.svg)](https://badge.fury.io/py/iredis)\n[![Chat on slack](https://badgen.net/badge/icon/slack?icon=slack&label)](https://join.slack.com/t/iredis/shared_invite/enQtNzQzMjkwOTI0MTE4LWFlNjQ4NzBlOTcyNmQ2MTQ4NGI2ODUxYTNhNTM5MmM4NjEyOTA4Y2VjNjQ1ZWQyNzMxYjY2M2E5N2U3ZDYxMTQ)\n[![Open in Cloud Shell](https://badgen.net/badge/run/GoogleCloudShell/blue?icon=terminal)](https://console.cloud.google.com/cloudshell/editor?cloudshell_git_repo=https://github.com/laixintao/iredis&cloudshell_print=docs/cloudshell/run-in-docker.txt)\n\n\nA Terminal Client for Redis with AutoCompletion and Syntax Highlighting. It is an alternative for redis-cli. IRedis is supposed to friendly for both user and redis-server, which means it is safe to use IRedis on production server. IRedis provide a `--strict` mode to prevent accidently running dangerous command, like `KEYS *`(See [here](https://redis.io/topics/latency), the *Latency generated by slow commands* section.\n\n![](https://raw.githubusercontent.com/laixintao/iredis/master/docs/assets/auto-complete.png)\n\n**This project is under development, any comments are welcome.**\n\n## Features\n\n- Advanced code completion. If you run command `KEYS` then run `DEL`, iredis will auto complete your command based on `KEYS` result.\n- Command validation: `CLUSTER MEET IP PORT`\n- Command highlighting, fully based on redis grammar. Any valide command in iredis shell is a valide redis command.\n- <kbd>Ctrl</kbd> + <kbd>C</kbd> to clear cureent line, won\'t exit redis-cli. Use <kbd>Ctrl</kbd> + <kbd>D</kbd>  \n- Say "Goodbye!" to you when you exit!\n- <kbd>Ctrl</kbd> + <kbd>R</kbd> to open **reverse-i-search** to search through command history.\n- Auto suggestions. (Like [fish shell](http://fishshell.com/).)\n- Support `--encode=utf-8`, to decode Redis\' bytes responses.\n- Command hint on bottom, include command syntax, supported redis version, and time complexity.\n- Offcial docs build in `HELP` command, try `HELP SET`!\n\n## Install\n\n```\npip install iredis\n```\n\n## Usage\n\n```\n$ iredis -h\n```\n\n## Development\n\n### Setup Environment\n\niredis favors [poetry](https://github.com/sdispater/poetry) as a packagement tool. You can setup a develop envioment on your computer easily.\n\nFirst, install poetry(You can do it in a python\'s virtualenv):\n\n```\npip install poetry\n```\n\nThen run(which euqals `pip install -e .`):\n\n```\npoetry install --develop=DEVELOP\n```\n\n### Development Logs\n\nSince this is a commandline tool, so we didn\'t write logs to stdout.\n\nYou can `tail -f iredis.log` to see logs, the log is pretty clear, you can see what actually happend from log files.\n\n### Command Reference\n\nThere is a full Redis command list in [commands.csv](docs/commands.csv) file, downloaded by:\n\n```\npython scripts/download_redis_commands.py > data/commands.csv\n```\n\n`commands.csv` is here only for test if redis.io was updated, do not package it into release.\n\nCurrent implemented commands: [command_syntax.csv](iredis/data/command_syntax.csv).\n\n## Planned Features\n\nPlease see issue. And you are welcome to submit one.\n\n## Related Projects\n\n- [redis-tui](https://github.com/mylxsw/redis-tui)\n',
    'author': 'laixintao',
    'author_email': 'laixintao1995@163.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/laixintao/iredis',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
